You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@openoffice.apache.org by da...@apache.org on 2016/08/01 04:31:57 UTC

svn commit: r1754701 [4/13] - in /openoffice/branches/gbuild-reintegration: ./ ext_libraries/apr-util/ ext_libraries/apr/ ext_sources/ main/ main/accessibility/inc/accessibility/standard/ main/autodoc/inc/ary/idl/ main/avmedia/source/framework/ main/ba...

Modified: openoffice/branches/gbuild-reintegration/main/framework/inc/services/desktop.hxx
URL: http://svn.apache.org/viewvc/openoffice/branches/gbuild-reintegration/main/framework/inc/services/desktop.hxx?rev=1754701&r1=1754700&r2=1754701&view=diff
==============================================================================
--- openoffice/branches/gbuild-reintegration/main/framework/inc/services/desktop.hxx (original)
+++ openoffice/branches/gbuild-reintegration/main/framework/inc/services/desktop.hxx Mon Aug  1 04:31:52 2016
@@ -489,7 +489,7 @@ class Desktop   :   // interfaces
           * Because these desktop instance closes documents and informs listener
           * only ... it does not really shutdown the whole application.
           *
-          * Btw: That wouldnt be possible by design ... because Desktop.terminate()
+          * Btw: That wouldn't be possible by design ... because Desktop.terminate()
           * has to return a boolean value about success ... it can't really shutdown the
           * process .-)
           *

Modified: openoffice/branches/gbuild-reintegration/main/framework/inc/services/frameloaderfactory.hxx
URL: http://svn.apache.org/viewvc/openoffice/branches/gbuild-reintegration/main/framework/inc/services/frameloaderfactory.hxx?rev=1754701&r1=1754700&r2=1754701&view=diff
==============================================================================
--- openoffice/branches/gbuild-reintegration/main/framework/inc/services/frameloaderfactory.hxx (original)
+++ openoffice/branches/gbuild-reintegration/main/framework/inc/services/frameloaderfactory.hxx Mon Aug  1 04:31:52 2016
@@ -81,7 +81,7 @@ struct tIMPLExtractedArguments
 /*-************************************************************************************************************//**
 	@short		factory to create frameloader-objects
 	@descr		These class can be used to create new loader for specified contents.
-				We use cached values of the registry to lay down, wich frameloader match
+				We use cached values of the registry to lay down, which frameloader match
 				a given URL or filtername. To do this, we use the XMultiServiceFactory-interface.
 
 	@ATTENTION	In a specialmode of these implementation we support a simple filterdetection.
@@ -100,7 +100,7 @@ struct tIMPLExtractedArguments
 	@devstatus	deprecated
 *//*-*************************************************************************************************************/
 
-class FrameLoaderFactory	:	public ThreadHelpBase							,		// Struct for right initalization of mutex member! Mst first of baseclasses
+class FrameLoaderFactory	:	public ThreadHelpBase							,		// Struct for right initialization of mutex member! Mst first of baseclasses
 								public ::cppu::WeakImplHelper3< ::com::sun::star::lang::XServiceInfo,::com::sun::star::lang::XMultiServiceFactory,::com::sun::star::container::XNameAccess >
 {
 	//-------------------------------------------------------------------------------------------------------------

Modified: openoffice/branches/gbuild-reintegration/main/framework/inc/services/layoutmanager.hxx
URL: http://svn.apache.org/viewvc/openoffice/branches/gbuild-reintegration/main/framework/inc/services/layoutmanager.hxx?rev=1754701&r1=1754700&r2=1754701&view=diff
==============================================================================
--- openoffice/branches/gbuild-reintegration/main/framework/inc/services/layoutmanager.hxx (original)
+++ openoffice/branches/gbuild-reintegration/main/framework/inc/services/layoutmanager.hxx Mon Aug  1 04:31:52 2016
@@ -102,7 +102,7 @@ namespace framework
     class LayoutManager : public  LayoutManager_Base                    ,
                           // base classes
                           // Order is necessary for right initialization!
-                          private ThreadHelpBase						,	// Struct for right initalization of mutex member! Must be first of baseclasses.
+                          private ThreadHelpBase						,	// Struct for right initialization of mutex member! Must be first of baseclasses.
                           public  ::cppu::OBroadcastHelper              ,
                           public  ILayoutNotifications                  ,
                           public  LayoutManager_PBase

Modified: openoffice/branches/gbuild-reintegration/main/framework/inc/services/license.hxx
URL: http://svn.apache.org/viewvc/openoffice/branches/gbuild-reintegration/main/framework/inc/services/license.hxx?rev=1754701&r1=1754700&r2=1754701&view=diff
==============================================================================
--- openoffice/branches/gbuild-reintegration/main/framework/inc/services/license.hxx (original)
+++ openoffice/branches/gbuild-reintegration/main/framework/inc/services/license.hxx Mon Aug  1 04:31:52 2016
@@ -69,7 +69,7 @@ namespace framework
                     public  css::util::XCloseable               ,
                     // base classes
                     // Order is necessary for right initialization!
-                    private ThreadHelpBase						, // Struct for right initalization of mutex member! Must be first of baseclasses.
+                    private ThreadHelpBase						, // Struct for right initialization of mutex member! Must be first of baseclasses.
                     public  ::cppu::OWeakObject                   // => XWeak, XInterface
     {
     private:

Modified: openoffice/branches/gbuild-reintegration/main/framework/inc/services/pluginframe.hxx
URL: http://svn.apache.org/viewvc/openoffice/branches/gbuild-reintegration/main/framework/inc/services/pluginframe.hxx?rev=1754701&r1=1754700&r2=1754701&view=diff
==============================================================================
--- openoffice/branches/gbuild-reintegration/main/framework/inc/services/pluginframe.hxx (original)
+++ openoffice/branches/gbuild-reintegration/main/framework/inc/services/pluginframe.hxx Mon Aug  1 04:31:52 2016
@@ -333,7 +333,7 @@ class cIMPL_MainThreadExecutorRequest
 	private:
 
 		eIMPL_PluginCommand								m_eCommand				;	/// switch to specify forward function
-		PlugInFrame*									m_pPluginInstance		;	/// instance wich has started this swicth mechanism and wish to called back from us
+		PlugInFrame*									m_pPluginInstance		;	/// instance which has started this swicth mechanism and wish to called back from us
 		css::uno::Reference< css::uno::XInterface >		m_xPluginInstance		;	/// reference to our plugin frame to prevent that plugin frame dies before we call back
 		css::uno::Any									m_aPlatformWindowHandle	;	///	parameter for XPluginInstance->createWindow()
 		sal_Bool										m_bEmbedded				;	///	parameter for XPluginInstance->createWindow()

Modified: openoffice/branches/gbuild-reintegration/main/framework/inc/services/sessionlistener.hxx
URL: http://svn.apache.org/viewvc/openoffice/branches/gbuild-reintegration/main/framework/inc/services/sessionlistener.hxx?rev=1754701&r1=1754700&r2=1754701&view=diff
==============================================================================
--- openoffice/branches/gbuild-reintegration/main/framework/inc/services/sessionlistener.hxx (original)
+++ openoffice/branches/gbuild-reintegration/main/framework/inc/services/sessionlistener.hxx Mon Aug  1 04:31:52 2016
@@ -95,7 +95,7 @@ class SessionListener :   // interfaces
                         public css::frame::XStatusListener,
                         public css::lang::XServiceInfo,
                         // baseclasses (order important for initialization!)
-                        // Struct for right initalization of mutex member! Must be the first one of baseclasses!
+                        // Struct for right initialization of mutex member! Must be the first one of baseclasses!
                         private ThreadHelpBase,
                         public  ::cppu::OWeakObject
 {

Modified: openoffice/branches/gbuild-reintegration/main/framework/inc/services/substitutepathvars.hxx
URL: http://svn.apache.org/viewvc/openoffice/branches/gbuild-reintegration/main/framework/inc/services/substitutepathvars.hxx?rev=1754701&r1=1754700&r2=1754701&view=diff
==============================================================================
--- openoffice/branches/gbuild-reintegration/main/framework/inc/services/substitutepathvars.hxx (original)
+++ openoffice/branches/gbuild-reintegration/main/framework/inc/services/substitutepathvars.hxx Mon Aug  1 04:31:52 2016
@@ -231,7 +231,7 @@ struct ReSubstUserVarOrder
 typedef std::list< ReSubstFixedVarOrder > ReSubstFixedVarOrderVector;
 typedef std::list< ReSubstUserVarOrder > ReSubstUserVarOrderVector;
 
-class SubstitutePathVariables : private ThreadHelpBase, // Struct for right initalization of mutex member! Must be first of baseclasses.
+class SubstitutePathVariables : private ThreadHelpBase, // Struct for right initialization of mutex member! Must be first of baseclasses.
                                 public ::cppu::WeakImplHelper2< ::com::sun::star::util::XStringSubstitution, css::lang::XServiceInfo >
 {
     friend class SubstitutePathVariables_Impl;

Modified: openoffice/branches/gbuild-reintegration/main/framework/inc/tabwin/tabwindow.hxx
URL: http://svn.apache.org/viewvc/openoffice/branches/gbuild-reintegration/main/framework/inc/tabwin/tabwindow.hxx?rev=1754701&r1=1754700&r2=1754701&view=diff
==============================================================================
--- openoffice/branches/gbuild-reintegration/main/framework/inc/tabwin/tabwindow.hxx (original)
+++ openoffice/branches/gbuild-reintegration/main/framework/inc/tabwin/tabwindow.hxx Mon Aug  1 04:31:52 2016
@@ -73,7 +73,7 @@ class TabWindow :  public ::com::sun::st
 				   public ::com::sun::star::awt::XWindowListener            ,
                    public ::com::sun::star::awt::XTopWindowListener         ,
                    public ::com::sun::star::awt::XSimpleTabController       ,
-                   protected ThreadHelpBase							        ,	// Struct for right initalization of mutex member! Must be first of baseclasses.
+                   protected ThreadHelpBase							        ,	// Struct for right initialization of mutex member! Must be first of baseclasses.
                    public ::cppu::OBroadcastHelper							,
                    public ::cppu::OPropertySetHelper						,   // => XPropertySet / XFastPropertySet / XMultiPropertySet
                    public ::cppu::OWeakObject

Modified: openoffice/branches/gbuild-reintegration/main/framework/inc/tabwin/tabwinfactory.hxx
URL: http://svn.apache.org/viewvc/openoffice/branches/gbuild-reintegration/main/framework/inc/tabwin/tabwinfactory.hxx?rev=1754701&r1=1754700&r2=1754701&view=diff
==============================================================================
--- openoffice/branches/gbuild-reintegration/main/framework/inc/tabwin/tabwinfactory.hxx (original)
+++ openoffice/branches/gbuild-reintegration/main/framework/inc/tabwin/tabwinfactory.hxx Mon Aug  1 04:31:52 2016
@@ -55,7 +55,7 @@
 namespace framework
 {
 
-class TabWinFactory :  protected ThreadHelpBase							        ,	// Struct for right initalization of mutex member! Must be first of baseclasses.
+class TabWinFactory :  protected ThreadHelpBase							        ,	// Struct for right initialization of mutex member! Must be first of baseclasses.
                        public ::cppu::WeakImplHelper2< ::com::sun::star::lang::XSingleComponentFactory, com::sun::star::lang::XServiceInfo>
 {
 	public:

Modified: openoffice/branches/gbuild-reintegration/main/framework/inc/threadhelp/gate.hxx
URL: http://svn.apache.org/viewvc/openoffice/branches/gbuild-reintegration/main/framework/inc/threadhelp/gate.hxx?rev=1754701&r1=1754700&r2=1754701&view=diff
==============================================================================
--- openoffice/branches/gbuild-reintegration/main/framework/inc/threadhelp/gate.hxx (original)
+++ openoffice/branches/gbuild-reintegration/main/framework/inc/threadhelp/gate.hxx Mon Aug  1 04:31:52 2016
@@ -62,7 +62,7 @@ namespace framework{
 					As a special feature you can open the gate a little bit by sing openGap().
 					Then all currently waiting threads are running immediately - but new ones are blocked!
 
-	@attention		To prevent us against wrong using, the default ctor, copy ctor and the =operator are maked private!
+	@attention		To prevent us against wrong using, the default ctor, copy ctor and the =operator are marked private!
 
     @implements     IGate
     @base           IGate

Modified: openoffice/branches/gbuild-reintegration/main/framework/inc/threadhelp/readguard.hxx
URL: http://svn.apache.org/viewvc/openoffice/branches/gbuild-reintegration/main/framework/inc/threadhelp/readguard.hxx?rev=1754701&r1=1754700&r2=1754701&view=diff
==============================================================================
--- openoffice/branches/gbuild-reintegration/main/framework/inc/threadhelp/readguard.hxx (original)
+++ openoffice/branches/gbuild-reintegration/main/framework/inc/threadhelp/readguard.hxx Mon Aug  1 04:31:52 2016
@@ -61,11 +61,11 @@ namespace framework{
 /*-************************************************************************************************************//**
 	@short          implement a guard to set read locks
 	@descr			This guard should be used to set a lock for reading object internal member.
-					Nobody can control it but don't use member after successfuly locking for writing!
+					Nobody can control it but don't use member after successfully locking for writing!
 					We never need a own mutex to safe our internal member access - because
 					a guard is used as function-local member only. There exists no multithreaded access to it really ...
 
-    @attention      a) To prevent us against wrong using, the default ctor, copy ctor and the =operator are maked private!
+    @attention      a) To prevent us against wrong using, the default ctor, copy ctor and the =operator are marked private!
                     b) Use interface "IRWLock" of set LockHelper only - because we must support a finer granularity of locking.
                        Interface "IMutex" should be used by easier guard implementations ... like "ResetableGuard"!
 

Modified: openoffice/branches/gbuild-reintegration/main/framework/inc/threadhelp/resetableguard.hxx
URL: http://svn.apache.org/viewvc/openoffice/branches/gbuild-reintegration/main/framework/inc/threadhelp/resetableguard.hxx?rev=1754701&r1=1754700&r2=1754701&view=diff
==============================================================================
--- openoffice/branches/gbuild-reintegration/main/framework/inc/threadhelp/resetableguard.hxx (original)
+++ openoffice/branches/gbuild-reintegration/main/framework/inc/threadhelp/resetableguard.hxx Mon Aug  1 04:31:52 2016
@@ -65,7 +65,7 @@ namespace framework{
 					A set bool flag inside protect this implementation against multiple lock() calls
 					without any unlock()! So the increasing of guarded mutex couldn't be greater then 1 ...
 
-    @attention      a) To prevent us against wrong using, the default ctor, copy ctor and the =operator are maked private!
+    @attention      a) To prevent us against wrong using, the default ctor, copy ctor and the =operator are marked private!
                     b) Use interface "IMutex" of set LockHelper only - because we must support an exclusiv locking.
                        Interface "IRWLock" should be used by special guard implementations ... like "ReadGuard" or "WriteGuard"!
 

Modified: openoffice/branches/gbuild-reintegration/main/framework/inc/threadhelp/transactionguard.hxx
URL: http://svn.apache.org/viewvc/openoffice/branches/gbuild-reintegration/main/framework/inc/threadhelp/transactionguard.hxx?rev=1754701&r1=1754700&r2=1754701&view=diff
==============================================================================
--- openoffice/branches/gbuild-reintegration/main/framework/inc/threadhelp/transactionguard.hxx (original)
+++ openoffice/branches/gbuild-reintegration/main/framework/inc/threadhelp/transactionguard.hxx Mon Aug  1 04:31:52 2016
@@ -63,7 +63,7 @@ namespace framework{
                     It's possible too, to enable automatically throwing of some exceptions for illegal
                     transaction requests ... e.g. interface call for already disposed objects.
 
-	@attention		To prevent us against wrong using, the default ctor, copy ctor and the =operator are maked private!
+	@attention		To prevent us against wrong using, the default ctor, copy ctor and the =operator are marked private!
 
 	@implements		-
     @base           INonCopyable

Modified: openoffice/branches/gbuild-reintegration/main/framework/inc/threadhelp/writeguard.hxx
URL: http://svn.apache.org/viewvc/openoffice/branches/gbuild-reintegration/main/framework/inc/threadhelp/writeguard.hxx?rev=1754701&r1=1754700&r2=1754701&view=diff
==============================================================================
--- openoffice/branches/gbuild-reintegration/main/framework/inc/threadhelp/writeguard.hxx (original)
+++ openoffice/branches/gbuild-reintegration/main/framework/inc/threadhelp/writeguard.hxx Mon Aug  1 04:31:52 2016
@@ -63,7 +63,7 @@ namespace framework{
 					We never need a own mutex to safe our internal member access - because
 					a guard is used as function-local member only. There exist no multithreaded access to it really ...
 
-    @attention      a) To prevent us against wrong using, the default ctor, copy ctor and the =operator are maked private!
+    @attention      a) To prevent us against wrong using, the default ctor, copy ctor and the =operator are marked private!
                     b) Use interface "IRWLock" of set LockHelper only - because we must support a finer granularity of locking.
                        Interface "IMutex" should be used by easier guard implementations ... like "ResetableGuard"!
 

Modified: openoffice/branches/gbuild-reintegration/main/framework/inc/uiconfiguration/imagemanager.hxx
URL: http://svn.apache.org/viewvc/openoffice/branches/gbuild-reintegration/main/framework/inc/uiconfiguration/imagemanager.hxx?rev=1754701&r1=1754700&r2=1754701&view=diff
==============================================================================
--- openoffice/branches/gbuild-reintegration/main/framework/inc/uiconfiguration/imagemanager.hxx (original)
+++ openoffice/branches/gbuild-reintegration/main/framework/inc/uiconfiguration/imagemanager.hxx Mon Aug  1 04:31:52 2016
@@ -75,7 +75,7 @@
 namespace framework
 {
     class ImageManagerImpl;
-    class ImageManager :    private ThreadHelpBase						                  ,	// Struct for right initalization of mutex member! Must be first of baseclasses.
+    class ImageManager :    private ThreadHelpBase						                  ,	// Struct for right initialization of mutex member! Must be first of baseclasses.
 							public ::cppu::WeakImplHelper2< ::com::sun::star::ui::XImageManager, css::lang::XServiceInfo>
     {
         public:

Modified: openoffice/branches/gbuild-reintegration/main/framework/inc/uiconfiguration/moduleimagemanager.hxx
URL: http://svn.apache.org/viewvc/openoffice/branches/gbuild-reintegration/main/framework/inc/uiconfiguration/moduleimagemanager.hxx?rev=1754701&r1=1754700&r2=1754701&view=diff
==============================================================================
--- openoffice/branches/gbuild-reintegration/main/framework/inc/uiconfiguration/moduleimagemanager.hxx (original)
+++ openoffice/branches/gbuild-reintegration/main/framework/inc/uiconfiguration/moduleimagemanager.hxx Mon Aug  1 04:31:52 2016
@@ -76,7 +76,7 @@ namespace framework
 {
     class ImageManagerImpl;
 
-    class ModuleImageManager :    private ThreadHelpBase						                  ,	// Struct for right initalization of mutex member! Must be first of baseclasses.
+    class ModuleImageManager :    private ThreadHelpBase						                  ,	// Struct for right initialization of mutex member! Must be first of baseclasses.
 							      public ::cppu::WeakImplHelper1< ::com::sun::star::ui::XImageManager>
     {
         public:

Modified: openoffice/branches/gbuild-reintegration/main/framework/inc/uiconfiguration/moduleuicfgsupplier.hxx
URL: http://svn.apache.org/viewvc/openoffice/branches/gbuild-reintegration/main/framework/inc/uiconfiguration/moduleuicfgsupplier.hxx?rev=1754701&r1=1754700&r2=1754701&view=diff
==============================================================================
--- openoffice/branches/gbuild-reintegration/main/framework/inc/uiconfiguration/moduleuicfgsupplier.hxx (original)
+++ openoffice/branches/gbuild-reintegration/main/framework/inc/uiconfiguration/moduleuicfgsupplier.hxx Mon Aug  1 04:31:52 2016
@@ -68,7 +68,7 @@ namespace framework
                                                  public com::sun::star::lang::XServiceInfo	,
                                                  public com::sun::star::lang::XComponent    ,
                                                  public ::com::sun::star::ui::XModuleUIConfigurationManagerSupplier      ,
-                                                 private ThreadHelpBase						,	// Struct for right initalization of mutex member! Must be first of baseclasses.
+                                                 private ThreadHelpBase						,	// Struct for right initialization of mutex member! Must be first of baseclasses.
 							                     public ::cppu::OWeakObject
     {
         public:

Modified: openoffice/branches/gbuild-reintegration/main/framework/inc/uiconfiguration/moduleuiconfigurationmanager.hxx
URL: http://svn.apache.org/viewvc/openoffice/branches/gbuild-reintegration/main/framework/inc/uiconfiguration/moduleuiconfigurationmanager.hxx?rev=1754701&r1=1754700&r2=1754701&view=diff
==============================================================================
--- openoffice/branches/gbuild-reintegration/main/framework/inc/uiconfiguration/moduleuiconfigurationmanager.hxx (original)
+++ openoffice/branches/gbuild-reintegration/main/framework/inc/uiconfiguration/moduleuiconfigurationmanager.hxx Mon Aug  1 04:31:52 2016
@@ -78,7 +78,7 @@ namespace framework
                                            public ::com::sun::star::ui::XUIConfigurationManager       ,
                                            public ::com::sun::star::ui::XModuleUIConfigurationManager ,
                                            public ::com::sun::star::ui::XUIConfigurationPersistence   ,
-                                           private ThreadHelpBase						,	// Struct for right initalization of mutex member! Must be first of baseclasses.
+                                           private ThreadHelpBase						,	// Struct for right initialization of mutex member! Must be first of baseclasses.
 							               public ::cppu::OWeakObject
     {
         public:

Modified: openoffice/branches/gbuild-reintegration/main/framework/inc/uiconfiguration/uiconfigurationmanager.hxx
URL: http://svn.apache.org/viewvc/openoffice/branches/gbuild-reintegration/main/framework/inc/uiconfiguration/uiconfigurationmanager.hxx?rev=1754701&r1=1754700&r2=1754701&view=diff
==============================================================================
--- openoffice/branches/gbuild-reintegration/main/framework/inc/uiconfiguration/uiconfigurationmanager.hxx (original)
+++ openoffice/branches/gbuild-reintegration/main/framework/inc/uiconfiguration/uiconfigurationmanager.hxx Mon Aug  1 04:31:52 2016
@@ -77,7 +77,7 @@ namespace framework
                                      public ::com::sun::star::ui::XUIConfigurationManager      ,
                                      public ::com::sun::star::ui::XUIConfigurationPersistence  ,
                                      public ::com::sun::star::ui::XUIConfigurationStorage      ,
-                                     private ThreadHelpBase						,	// Struct for right initalization of mutex member! Must be first of baseclasses.
+                                     private ThreadHelpBase						,	// Struct for right initialization of mutex member! Must be first of baseclasses.
 							         public ::cppu::OWeakObject
     {
         public:

Modified: openoffice/branches/gbuild-reintegration/main/framework/inc/uiconfiguration/windowstateconfiguration.hxx
URL: http://svn.apache.org/viewvc/openoffice/branches/gbuild-reintegration/main/framework/inc/uiconfiguration/windowstateconfiguration.hxx?rev=1754701&r1=1754700&r2=1754701&view=diff
==============================================================================
--- openoffice/branches/gbuild-reintegration/main/framework/inc/uiconfiguration/windowstateconfiguration.hxx (original)
+++ openoffice/branches/gbuild-reintegration/main/framework/inc/uiconfiguration/windowstateconfiguration.hxx Mon Aug  1 04:31:52 2016
@@ -76,7 +76,7 @@ namespace framework
 #define WINDOWSTATE_PROPERTY_CONTEXTACTIVE  "ContextActive"
 
 class ConfigurationAccess_Windows;
-class WindowStateConfiguration :  private ThreadHelpBase						,	// Struct for right initalization of mutex member! Must be first of baseclasses.
+class WindowStateConfiguration :  private ThreadHelpBase						,	// Struct for right initialization of mutex member! Must be first of baseclasses.
 							      public ::cppu::WeakImplHelper2< ::com::sun::star::container::XNameAccess, css::lang::XServiceInfo>
 {
 	public:

Modified: openoffice/branches/gbuild-reintegration/main/framework/inc/uielement/uicommanddescription.hxx
URL: http://svn.apache.org/viewvc/openoffice/branches/gbuild-reintegration/main/framework/inc/uielement/uicommanddescription.hxx?rev=1754701&r1=1754700&r2=1754701&view=diff
==============================================================================
--- openoffice/branches/gbuild-reintegration/main/framework/inc/uielement/uicommanddescription.hxx (original)
+++ openoffice/branches/gbuild-reintegration/main/framework/inc/uielement/uicommanddescription.hxx Mon Aug  1 04:31:52 2016
@@ -57,7 +57,7 @@
 
 namespace framework
 {
-class UICommandDescription :  private ThreadHelpBase						,	// Struct for right initalization of mutex member! Must be first of baseclasses.
+class UICommandDescription :  private ThreadHelpBase						,	// Struct for right initialization of mutex member! Must be first of baseclasses.
 							  public ::cppu::WeakImplHelper2< com::sun::star::lang::XServiceInfo		,
 							                                  com::sun::star::container::XNameAccess >
 {

Modified: openoffice/branches/gbuild-reintegration/main/framework/inc/uifactory/addonstoolboxfactory.hxx
URL: http://svn.apache.org/viewvc/openoffice/branches/gbuild-reintegration/main/framework/inc/uifactory/addonstoolboxfactory.hxx?rev=1754701&r1=1754700&r2=1754701&view=diff
==============================================================================
--- openoffice/branches/gbuild-reintegration/main/framework/inc/uifactory/addonstoolboxfactory.hxx (original)
+++ openoffice/branches/gbuild-reintegration/main/framework/inc/uifactory/addonstoolboxfactory.hxx Mon Aug  1 04:31:52 2016
@@ -57,7 +57,7 @@
 namespace framework
 {
 
-class AddonsToolBoxFactory :  protected ThreadHelpBase							        ,	// Struct for right initalization of mutex member! Must be first of baseclasses.
+class AddonsToolBoxFactory :  protected ThreadHelpBase							        ,	// Struct for right initialization of mutex member! Must be first of baseclasses.
 						      public ::cppu::WeakImplHelper2< com::sun::star::lang::XServiceInfo		,
 							                                  com::sun::star::ui::XUIElementFactory >
 {

Modified: openoffice/branches/gbuild-reintegration/main/framework/inc/uifactory/menubarfactory.hxx
URL: http://svn.apache.org/viewvc/openoffice/branches/gbuild-reintegration/main/framework/inc/uifactory/menubarfactory.hxx?rev=1754701&r1=1754700&r2=1754701&view=diff
==============================================================================
--- openoffice/branches/gbuild-reintegration/main/framework/inc/uifactory/menubarfactory.hxx (original)
+++ openoffice/branches/gbuild-reintegration/main/framework/inc/uifactory/menubarfactory.hxx Mon Aug  1 04:31:52 2016
@@ -54,7 +54,7 @@
 
 namespace framework
 {
-    class MenuBarFactory :  protected ThreadHelpBase							        ,	// Struct for right initalization of mutex member! Must be first of baseclasses.
+    class MenuBarFactory :  protected ThreadHelpBase							        ,	// Struct for right initialization of mutex member! Must be first of baseclasses.
 							public ::cppu::WeakImplHelper2< com::sun::star::lang::XServiceInfo,
                                                             ::com::sun::star::ui::XUIElementFactory>
     {

Modified: openoffice/branches/gbuild-reintegration/main/framework/inc/uifactory/uicontrollerfactory.hxx
URL: http://svn.apache.org/viewvc/openoffice/branches/gbuild-reintegration/main/framework/inc/uifactory/uicontrollerfactory.hxx?rev=1754701&r1=1754700&r2=1754701&view=diff
==============================================================================
--- openoffice/branches/gbuild-reintegration/main/framework/inc/uifactory/uicontrollerfactory.hxx (original)
+++ openoffice/branches/gbuild-reintegration/main/framework/inc/uifactory/uicontrollerfactory.hxx Mon Aug  1 04:31:52 2016
@@ -39,7 +39,7 @@ namespace framework
 {
 
 class ConfigurationAccess_ControllerFactory;
-class UIControllerFactory :  protected ThreadHelpBase, // Struct for right initalization of mutex member! Must be first of baseclasses.
+class UIControllerFactory :  protected ThreadHelpBase, // Struct for right initialization of mutex member! Must be first of baseclasses.
                              public ::cppu::WeakImplHelper2<
                                  com::sun::star::lang::XServiceInfo,
                                  com::sun::star::frame::XUIControllerFactory >

Modified: openoffice/branches/gbuild-reintegration/main/framework/inc/uifactory/uielementfactorymanager.hxx
URL: http://svn.apache.org/viewvc/openoffice/branches/gbuild-reintegration/main/framework/inc/uifactory/uielementfactorymanager.hxx?rev=1754701&r1=1754700&r2=1754701&view=diff
==============================================================================
--- openoffice/branches/gbuild-reintegration/main/framework/inc/uifactory/uielementfactorymanager.hxx (original)
+++ openoffice/branches/gbuild-reintegration/main/framework/inc/uifactory/uielementfactorymanager.hxx Mon Aug  1 04:31:52 2016
@@ -113,7 +113,7 @@ namespace framework
 };
 
 
-class UIElementFactoryManager :  private ThreadHelpBase							                    ,	// Struct for right initalization of mutex member! Must be first of baseclasses.
+class UIElementFactoryManager :  private ThreadHelpBase							                    ,	// Struct for right initialization of mutex member! Must be first of baseclasses.
                                  public ::cppu::WeakImplHelper3< ::com::sun::star::lang::XServiceInfo,
                                                                  ::com::sun::star::ui::XUIElementFactory,
                                                                  ::com::sun::star::ui::XUIElementFactoryRegistration>

Modified: openoffice/branches/gbuild-reintegration/main/framework/inc/uifactory/windowcontentfactorymanager.hxx
URL: http://svn.apache.org/viewvc/openoffice/branches/gbuild-reintegration/main/framework/inc/uifactory/windowcontentfactorymanager.hxx?rev=1754701&r1=1754700&r2=1754701&view=diff
==============================================================================
--- openoffice/branches/gbuild-reintegration/main/framework/inc/uifactory/windowcontentfactorymanager.hxx (original)
+++ openoffice/branches/gbuild-reintegration/main/framework/inc/uifactory/windowcontentfactorymanager.hxx Mon Aug  1 04:31:52 2016
@@ -57,7 +57,7 @@ namespace framework
 {
 
 class ConfigurationAccess_FactoryManager;
-class WindowContentFactoryManager : private ThreadHelpBase							              ,	// Struct for right initalization of mutex member! Must be first of baseclasses.
+class WindowContentFactoryManager : private ThreadHelpBase							              ,	// Struct for right initialization of mutex member! Must be first of baseclasses.
 						            public ::cppu::WeakImplHelper2< com::sun::star::lang::XServiceInfo		              ,
                                                              com::sun::star::lang::XSingleComponentFactory>
 {

Modified: openoffice/branches/gbuild-reintegration/main/framework/inc/xml/acceleratorconfigurationreader.hxx
URL: http://svn.apache.org/viewvc/openoffice/branches/gbuild-reintegration/main/framework/inc/xml/acceleratorconfigurationreader.hxx?rev=1754701&r1=1754700&r2=1754701&view=diff
==============================================================================
--- openoffice/branches/gbuild-reintegration/main/framework/inc/xml/acceleratorconfigurationreader.hxx (original)
+++ openoffice/branches/gbuild-reintegration/main/framework/inc/xml/acceleratorconfigurationreader.hxx Mon Aug  1 04:31:52 2016
@@ -105,12 +105,12 @@ class AcceleratorConfigurationReader : p
     
         //---------------------------------------
         /** @short  used to detect if an accelerator list
-                    occures recursive inside xml. */
+                    occurs recursive inside xml. */
 		sal_Bool m_bInsideAcceleratorList;
         
         //---------------------------------------
         /** @short  used to detect if an accelerator item
-                    occures recursive inside xml. */
+                    occurs recursive inside xml. */
 		sal_Bool m_bInsideAcceleratorItem;
         
         //---------------------------------------

Modified: openoffice/branches/gbuild-reintegration/main/framework/inc/xml/eventsdocumenthandler.hxx
URL: http://svn.apache.org/viewvc/openoffice/branches/gbuild-reintegration/main/framework/inc/xml/eventsdocumenthandler.hxx?rev=1754701&r1=1754700&r2=1754701&view=diff
==============================================================================
--- openoffice/branches/gbuild-reintegration/main/framework/inc/xml/eventsdocumenthandler.hxx (original)
+++ openoffice/branches/gbuild-reintegration/main/framework/inc/xml/eventsdocumenthandler.hxx Mon Aug  1 04:31:52 2016
@@ -56,7 +56,7 @@ namespace framework{
 //*****************************************************************************************************************
 // Hash code function for using in all hash maps of follow implementation.
 
-class FWE_DLLPUBLIC OReadEventsDocumentHandler :	private ThreadHelpBase,	// Struct for right initalization of lock member! Must be first of baseclasses.
+class FWE_DLLPUBLIC OReadEventsDocumentHandler :	private ThreadHelpBase,	// Struct for right initialization of lock member! Must be first of baseclasses.
 									public ::cppu::WeakImplHelper1< ::com::sun::star::xml::sax::XDocumentHandler >
 {
 	public:
@@ -146,7 +146,7 @@ class FWE_DLLPUBLIC OReadEventsDocumentH
 		::com::sun::star::uno::Reference< ::com::sun::star::xml::sax::XLocator >	m_xLocator;
 };
 
-class FWE_DLLPUBLIC OWriteEventsDocumentHandler : private ThreadHelpBase // Struct for right initalization of lock member! Must be first of baseclasses.
+class FWE_DLLPUBLIC OWriteEventsDocumentHandler : private ThreadHelpBase // Struct for right initialization of lock member! Must be first of baseclasses.
 {
 	public:
 		OWriteEventsDocumentHandler(

Modified: openoffice/branches/gbuild-reintegration/main/framework/inc/xml/imagesdocumenthandler.hxx
URL: http://svn.apache.org/viewvc/openoffice/branches/gbuild-reintegration/main/framework/inc/xml/imagesdocumenthandler.hxx?rev=1754701&r1=1754700&r2=1754701&view=diff
==============================================================================
--- openoffice/branches/gbuild-reintegration/main/framework/inc/xml/imagesdocumenthandler.hxx (original)
+++ openoffice/branches/gbuild-reintegration/main/framework/inc/xml/imagesdocumenthandler.hxx Mon Aug  1 04:31:52 2016
@@ -53,7 +53,7 @@ namespace framework{
 //*****************************************************************************************************************
 // Hash code function for using in all hash maps of follow implementation.
 
-class OReadImagesDocumentHandler : private ThreadHelpBase,	// Struct for right initalization of lock member! Must be first of baseclasses.
+class OReadImagesDocumentHandler : private ThreadHelpBase,	// Struct for right initialization of lock member! Must be first of baseclasses.
 								   public ::cppu::WeakImplHelper1< ::com::sun::star::xml::sax::XDocumentHandler >
 {
 	public:
@@ -154,7 +154,7 @@ class OReadImagesDocumentHandler : priva
 		::com::sun::star::uno::Reference< ::com::sun::star::xml::sax::XLocator >	m_xLocator;
 };
 
-class OWriteImagesDocumentHandler : private ThreadHelpBase // Struct for right initalization of lock member! Must be first of baseclasses.
+class OWriteImagesDocumentHandler : private ThreadHelpBase // Struct for right initialization of lock member! Must be first of baseclasses.
 {
 	public:
 		OWriteImagesDocumentHandler(

Modified: openoffice/branches/gbuild-reintegration/main/framework/inc/xml/menudocumenthandler.hxx
URL: http://svn.apache.org/viewvc/openoffice/branches/gbuild-reintegration/main/framework/inc/xml/menudocumenthandler.hxx?rev=1754701&r1=1754700&r2=1754701&view=diff
==============================================================================
--- openoffice/branches/gbuild-reintegration/main/framework/inc/xml/menudocumenthandler.hxx (original)
+++ openoffice/branches/gbuild-reintegration/main/framework/inc/xml/menudocumenthandler.hxx Mon Aug  1 04:31:52 2016
@@ -52,7 +52,7 @@
 
 namespace framework{
 
-class FWE_DLLPUBLIC ReadMenuDocumentHandlerBase : public ThreadHelpBase,	// Struct for right initalization of mutex member! Must be first of baseclasses.
+class FWE_DLLPUBLIC ReadMenuDocumentHandlerBase : public ThreadHelpBase,	// Struct for right initialization of mutex member! Must be first of baseclasses.
 									public ::cppu::WeakImplHelper1< ::com::sun::star::xml::sax::XDocumentHandler >
 {
 	public:

Modified: openoffice/branches/gbuild-reintegration/main/framework/inc/xml/saxnamespacefilter.hxx
URL: http://svn.apache.org/viewvc/openoffice/branches/gbuild-reintegration/main/framework/inc/xml/saxnamespacefilter.hxx?rev=1754701&r1=1754700&r2=1754701&view=diff
==============================================================================
--- openoffice/branches/gbuild-reintegration/main/framework/inc/xml/saxnamespacefilter.hxx (original)
+++ openoffice/branches/gbuild-reintegration/main/framework/inc/xml/saxnamespacefilter.hxx Mon Aug  1 04:31:52 2016
@@ -41,7 +41,7 @@
 namespace framework
 {
 
-class FWE_DLLPUBLIC SaxNamespaceFilter : public ThreadHelpBase,	// Struct for right initalization of mutex member! Must be first of baseclasses.
+class FWE_DLLPUBLIC SaxNamespaceFilter : public ThreadHelpBase,	// Struct for right initialization of mutex member! Must be first of baseclasses.
 						   public ::cppu::WeakImplHelper1< ::com::sun::star::xml::sax::XDocumentHandler >
 {
 	public:

Modified: openoffice/branches/gbuild-reintegration/main/framework/inc/xml/statusbardocumenthandler.hxx
URL: http://svn.apache.org/viewvc/openoffice/branches/gbuild-reintegration/main/framework/inc/xml/statusbardocumenthandler.hxx?rev=1754701&r1=1754700&r2=1754701&view=diff
==============================================================================
--- openoffice/branches/gbuild-reintegration/main/framework/inc/xml/statusbardocumenthandler.hxx (original)
+++ openoffice/branches/gbuild-reintegration/main/framework/inc/xml/statusbardocumenthandler.hxx Mon Aug  1 04:31:52 2016
@@ -56,7 +56,7 @@ namespace framework{
 //*****************************************************************************************************************
 // Hash code function for using in all hash maps of follow implementation.
 
-class FWE_DLLPUBLIC OReadStatusBarDocumentHandler :	private ThreadHelpBase,	// Struct for right initalization of lock member! Must be first of baseclasses.
+class FWE_DLLPUBLIC OReadStatusBarDocumentHandler :	private ThreadHelpBase,	// Struct for right initialization of lock member! Must be first of baseclasses.
 										public ::cppu::WeakImplHelper1< ::com::sun::star::xml::sax::XDocumentHandler >
 {
 	public:
@@ -145,7 +145,7 @@ class FWE_DLLPUBLIC OReadStatusBarDocume
 		::com::sun::star::uno::Reference< ::com::sun::star::xml::sax::XLocator >	        m_xLocator;
 };
 
-class FWE_DLLPUBLIC OWriteStatusBarDocumentHandler : private ThreadHelpBase // Struct for right initalization of lock member! Must be first of baseclasses.
+class FWE_DLLPUBLIC OWriteStatusBarDocumentHandler : private ThreadHelpBase // Struct for right initialization of lock member! Must be first of baseclasses.
 {
 	public:
 		OWriteStatusBarDocumentHandler(

Modified: openoffice/branches/gbuild-reintegration/main/framework/inc/xml/toolboxdocumenthandler.hxx
URL: http://svn.apache.org/viewvc/openoffice/branches/gbuild-reintegration/main/framework/inc/xml/toolboxdocumenthandler.hxx?rev=1754701&r1=1754700&r2=1754701&view=diff
==============================================================================
--- openoffice/branches/gbuild-reintegration/main/framework/inc/xml/toolboxdocumenthandler.hxx (original)
+++ openoffice/branches/gbuild-reintegration/main/framework/inc/xml/toolboxdocumenthandler.hxx Mon Aug  1 04:31:52 2016
@@ -50,7 +50,7 @@ namespace framework{
 //*****************************************************************************************************************
 // Hash code function for using in all hash maps of follow implementation.
 
-class FWE_DLLPUBLIC OReadToolBoxDocumentHandler : private ThreadHelpBase,   // Struct for right initalization of lock member! Must be first of baseclasses.
+class FWE_DLLPUBLIC OReadToolBoxDocumentHandler : private ThreadHelpBase,   // Struct for right initialization of lock member! Must be first of baseclasses.
                                     public ::cppu::WeakImplHelper1< ::com::sun::star::xml::sax::XDocumentHandler >
 {
     public:
@@ -166,7 +166,7 @@ class FWE_DLLPUBLIC OReadToolBoxDocument
 };
 
 
-class FWE_DLLPUBLIC OWriteToolBoxDocumentHandler : private ThreadHelpBase   // Struct for right initalization of lock member! Must be first of baseclasses.
+class FWE_DLLPUBLIC OWriteToolBoxDocumentHandler : private ThreadHelpBase   // Struct for right initialization of lock member! Must be first of baseclasses.
 {
     public:
             OWriteToolBoxDocumentHandler(

Modified: openoffice/branches/gbuild-reintegration/main/framework/qa/complex/XUserInputInterception/EventTest.java
URL: http://svn.apache.org/viewvc/openoffice/branches/gbuild-reintegration/main/framework/qa/complex/XUserInputInterception/EventTest.java?rev=1754701&r1=1754700&r2=1754701&view=diff
==============================================================================
--- openoffice/branches/gbuild-reintegration/main/framework/qa/complex/XUserInputInterception/EventTest.java (original)
+++ openoffice/branches/gbuild-reintegration/main/framework/qa/complex/XUserInputInterception/EventTest.java Mon Aug  1 04:31:52 2016
@@ -482,7 +482,7 @@ public class EventTest {
         
         /**
          * Creates an instacne of this class. The parameter <CODE>eType</CODE> represents
-         * the kind of event wich will be triggert at <CODE>run()</CODE>
+         * the kind of event which will be triggert at <CODE>run()</CODE>
          * @param model the model of a document
          * @param eType the kind of event which should be trigger
          */
@@ -493,7 +493,7 @@ public class EventTest {
         }
         
         /**
-         * Triggers the event wich is represented by <CODE>eventType</CODE>
+         * Triggers the event which is represented by <CODE>eventType</CODE>
          * The scenarios are:
          * <ul>
          *    <li>EventTest.EventTriggerType.MOUSE_KLICK_INTO_DOC

Modified: openoffice/branches/gbuild-reintegration/main/framework/qa/complex/framework/autosave/Protocol.java
URL: http://svn.apache.org/viewvc/openoffice/branches/gbuild-reintegration/main/framework/qa/complex/framework/autosave/Protocol.java?rev=1754701&r1=1754700&r2=1754701&view=diff
==============================================================================
--- openoffice/branches/gbuild-reintegration/main/framework/qa/complex/framework/autosave/Protocol.java (original)
+++ openoffice/branches/gbuild-reintegration/main/framework/qa/complex/framework/autosave/Protocol.java Mon Aug  1 04:31:52 2016
@@ -434,7 +434,7 @@ public class Protocol extends JComponent
         }
 
         /**
-         * create a colored table cell formated as HTML.
+         * create a colored table cell formatted as HTML.
          *
          * @param   sCell
          *          an outside string buffer, which can be
@@ -756,7 +756,7 @@ public class Protocol extends JComponent
     /**
      * returns a generic html header for generating html log files
      *
-     * It's used from the method finish() to generate a valid html formated file.
+     * It's used from the method finish() to generate a valid html formatted file.
      * For that its necessary to open some special html targets like e.g. <html>.
      *
      * @return  A string, which includes the whole header.

Modified: openoffice/branches/gbuild-reintegration/main/framework/qa/complex/framework/recovery/RecoveryTools.java
URL: http://svn.apache.org/viewvc/openoffice/branches/gbuild-reintegration/main/framework/qa/complex/framework/recovery/RecoveryTools.java?rev=1754701&r1=1754700&r2=1754701&view=diff
==============================================================================
--- openoffice/branches/gbuild-reintegration/main/framework/qa/complex/framework/recovery/RecoveryTools.java (original)
+++ openoffice/branches/gbuild-reintegration/main/framework/qa/complex/framework/recovery/RecoveryTools.java Mon Aug  1 04:31:52 2016
@@ -288,7 +288,7 @@ public class RecoveryTools {
      * This function uses accessibility to handle modal dialogs like the
      * "Are you sure" dialog.
      * It cklick the named button given in parameter <CODE>buttonName</CODE>
-     * @param buttonName the name of the button wich should be chlicked
+     * @param buttonName the name of the button which should be chlicked
      */    
     public void handleModalDialog(XMultiServiceFactory xMSF, String buttonName)
                 throws com.sun.star.accessibility.IllegalAccessibleComponentStateException

Modified: openoffice/branches/gbuild-reintegration/main/framework/source/accelerators/keymapping.cxx
URL: http://svn.apache.org/viewvc/openoffice/branches/gbuild-reintegration/main/framework/source/accelerators/keymapping.cxx?rev=1754701&r1=1754700&r2=1754701&view=diff
==============================================================================
--- openoffice/branches/gbuild-reintegration/main/framework/source/accelerators/keymapping.cxx (original)
+++ openoffice/branches/gbuild-reintegration/main/framework/source/accelerators/keymapping.cxx Mon Aug  1 04:31:52 2016
@@ -182,7 +182,7 @@ sal_uInt16 KeyMapping::mapIdentifierToCo
     if (pIt != m_lIdentifierHash.end())
         return pIt->second;                
     
-    // Its not well known identifier - but may be a pure key code formated as string ...
+    // Its not well known identifier - but may be a pure key code formatted as string ...
     // Check and convert it!
     sal_uInt16 nCode = 0;
     if (!KeyMapping::impl_st_interpretIdentifierAsPureKeyCode(sIdentifier, nCode))

Modified: openoffice/branches/gbuild-reintegration/main/framework/source/application/login.cxx
URL: http://svn.apache.org/viewvc/openoffice/branches/gbuild-reintegration/main/framework/source/application/login.cxx?rev=1754701&r1=1754700&r2=1754701&view=diff
==============================================================================
--- openoffice/branches/gbuild-reintegration/main/framework/source/application/login.cxx (original)
+++ openoffice/branches/gbuild-reintegration/main/framework/source/application/login.cxx Mon Aug  1 04:31:52 2016
@@ -249,7 +249,7 @@ void LoginApplication::impl_parseCommand
 {
 	// Use vos::OStartupInfo for access to command line.
 	// Step over all arguments, search for supported ones and try to get his values.
-	// Set it on our member. Caller of this method must control setted values.
+	// Set it on our member. Caller of this method must control set values.
 	OStartupInfo aInfo;
 
 	sal_uInt32	nCount		=	aInfo.getCommandArgCount()	;

Modified: openoffice/branches/gbuild-reintegration/main/framework/source/dispatch/dispatchprovider.cxx
URL: http://svn.apache.org/viewvc/openoffice/branches/gbuild-reintegration/main/framework/source/dispatch/dispatchprovider.cxx?rev=1754701&r1=1754700&r2=1754701&view=diff
==============================================================================
--- openoffice/branches/gbuild-reintegration/main/framework/source/dispatch/dispatchprovider.cxx (original)
+++ openoffice/branches/gbuild-reintegration/main/framework/source/dispatch/dispatchprovider.cxx Mon Aug  1 04:31:52 2016
@@ -460,7 +460,7 @@ css::uno::Reference< css::frame::XDispat
     //-----------------------------------------------------------------------------------------------------
     // I.VII) "_self", ""
     //  Our owner frame should handle this URL. But we can't do it for all of them.
-    //  So we ask the internal setted controller first. If he disagree we try to find a registered
+    //  So we ask the internal set controller first. If he disagree we try to find a registered
     //  protocol handler. If this failed too - we check for a loadable content and in case of true
     //  we load it into the frame by returning specilized dispatch object.
     //-----------------------------------------------------------------------------------------------------

Modified: openoffice/branches/gbuild-reintegration/main/framework/source/dispatch/mailtodispatcher.cxx
URL: http://svn.apache.org/viewvc/openoffice/branches/gbuild-reintegration/main/framework/source/dispatch/mailtodispatcher.cxx?rev=1754701&r1=1754700&r2=1754701&view=diff
==============================================================================
--- openoffice/branches/gbuild-reintegration/main/framework/source/dispatch/mailtodispatcher.cxx (original)
+++ openoffice/branches/gbuild-reintegration/main/framework/source/dispatch/mailtodispatcher.cxx Mon Aug  1 04:31:52 2016
@@ -138,7 +138,7 @@ MailToDispatcher::~MailToDispatcher()
     @short      decide if this dispatch implementation can be used for requested URL or not
     @descr      A protocol handler is registerd for an URL pattern inside configuration and will
                 be asked by the generic dispatch mechanism inside framework, if he can handle this
-                special URL wich match his registration. He can agree by returning of a valid dispatch
+                special URL which match his registration. He can agree by returning of a valid dispatch
                 instance or disagree by returning <NULL/>.
                 We don't create new dispatch instances here really - we return THIS as result to handle it
                 at the same implementation.

Modified: openoffice/branches/gbuild-reintegration/main/framework/source/dispatch/oxt_handler.cxx
URL: http://svn.apache.org/viewvc/openoffice/branches/gbuild-reintegration/main/framework/source/dispatch/oxt_handler.cxx?rev=1754701&r1=1754700&r2=1754701&view=diff
==============================================================================
--- openoffice/branches/gbuild-reintegration/main/framework/source/dispatch/oxt_handler.cxx (original)
+++ openoffice/branches/gbuild-reintegration/main/framework/source/dispatch/oxt_handler.cxx Mon Aug  1 04:31:52 2016
@@ -224,7 +224,7 @@ void SAL_CALL Oxt_Handler::dispatchWithN
     if (m_aPlayer.SetSoundName(aURL.Complete))
     {
         // OK- we can start async playing ...
-        // Count this request and initialize self-holder against dieing by uno ref count ...
+        // Count this request and initialize self-holder against dying by uno ref count ...
         m_xSelfHold = css::uno::Reference< css::uno::XInterface >(static_cast< ::cppu::OWeakObject* >(this), css::uno::UNO_QUERY);
         m_aPlayer.Play();
     }

Modified: openoffice/branches/gbuild-reintegration/main/framework/source/dispatch/servicehandler.cxx
URL: http://svn.apache.org/viewvc/openoffice/branches/gbuild-reintegration/main/framework/source/dispatch/servicehandler.cxx?rev=1754701&r1=1754700&r2=1754701&view=diff
==============================================================================
--- openoffice/branches/gbuild-reintegration/main/framework/source/dispatch/servicehandler.cxx (original)
+++ openoffice/branches/gbuild-reintegration/main/framework/source/dispatch/servicehandler.cxx Mon Aug  1 04:31:52 2016
@@ -137,7 +137,7 @@ ServiceHandler::~ServiceHandler()
     @short      decide if this dispatch implementation can be used for requested URL or not
     @descr      A protocol handler is registerd for an URL pattern inside configuration and will
                 be asked by the generic dispatch mechanism inside framework, if he can handle this
-                special URL wich match his registration. He can agree by returning of a valid dispatch
+                special URL which match his registration. He can agree by returning of a valid dispatch
                 instance or disagree by returning <NULL/>.
                 We don't create new dispatch instances here really - we return THIS as result to handle it
                 at the same implementation.

Modified: openoffice/branches/gbuild-reintegration/main/framework/source/fwi/classes/converter.cxx
URL: http://svn.apache.org/viewvc/openoffice/branches/gbuild-reintegration/main/framework/source/fwi/classes/converter.cxx?rev=1754701&r1=1754700&r2=1754701&view=diff
==============================================================================
--- openoffice/branches/gbuild-reintegration/main/framework/source/fwi/classes/converter.cxx (original)
+++ openoffice/branches/gbuild-reintegration/main/framework/source/fwi/classes/converter.cxx Mon Aug  1 04:31:52 2016
@@ -263,7 +263,7 @@ DateTime Converter::convert_String2DateT
     sal_Int32 nMin   = aSource.GetMin();
     sal_Int32 nSec   = aSource.GetSec();
 
-    // write year formated as "YYYY"
+    // write year formatted as "YYYY"
     if (nYear<10)
         sBuffer.appendAscii("000");
     else
@@ -275,31 +275,31 @@ DateTime Converter::convert_String2DateT
     sBuffer.append( (sal_Int32)nYear );
 
     sBuffer.appendAscii("-");
-    // write month formated as "MM"
+    // write month formatted as "MM"
     if (nMonth<10)
         sBuffer.appendAscii("0");
     sBuffer.append( (sal_Int32)nMonth );
 
     sBuffer.appendAscii("-");
-    // write day formated as "DD"
+    // write day formatted as "DD"
     if (nDay<10)
         sBuffer.appendAscii("0");
     sBuffer.append( (sal_Int32)nDay );
 
     sBuffer.appendAscii("T");
-    // write hours formated as "hh"
+    // write hours formatted as "hh"
     if (nHour<10)
         sBuffer.appendAscii("0");
     sBuffer.append( (sal_Int32)nHour );
 
     sBuffer.appendAscii(":");
-    // write min formated as "mm"
+    // write min formatted as "mm"
     if (nMin<10)
         sBuffer.appendAscii("0");
     sBuffer.append( (sal_Int32)nMin );
 
     sBuffer.appendAscii(":");
-    // write sec formated as "ss"
+    // write sec formatted as "ss"
     if (nSec<10)
         sBuffer.appendAscii("0");
     sBuffer.append( (sal_Int32)nSec );

Modified: openoffice/branches/gbuild-reintegration/main/framework/source/fwi/threadhelp/lockhelper.cxx
URL: http://svn.apache.org/viewvc/openoffice/branches/gbuild-reintegration/main/framework/source/fwi/threadhelp/lockhelper.cxx?rev=1754701&r1=1754700&r2=1754701&view=diff
==============================================================================
--- openoffice/branches/gbuild-reintegration/main/framework/source/fwi/threadhelp/lockhelper.cxx (original)
+++ openoffice/branches/gbuild-reintegration/main/framework/source/fwi/threadhelp/lockhelper.cxx Mon Aug  1 04:31:52 2016
@@ -426,7 +426,7 @@ void LockHelper::downgradeWriteAccess()
     @param      -
     @return     A reference to a static mutex/lock member.
 
-    @onerror    No error should occure.
+    @onerror    No error should occur.
 *//*-*************************************************************************************************************/
 LockHelper& LockHelper::getGlobalLock( ::vos::IMutex* pSolarMutex )
 {
@@ -465,7 +465,7 @@ LockHelper& LockHelper::getGlobalLock( :
     @param      -
     @return     A reference to a shared mutex.
 
-    @onerror    No error should occure.
+    @onerror    No error should occur.
 *//*-*************************************************************************************************************/
 ::osl::Mutex& LockHelper::getShareableOslMutex()
 {

Modified: openoffice/branches/gbuild-reintegration/main/framework/source/fwi/threadhelp/transactionmanager.cxx
URL: http://svn.apache.org/viewvc/openoffice/branches/gbuild-reintegration/main/framework/source/fwi/threadhelp/transactionmanager.cxx?rev=1754701&r1=1754700&r2=1754701&view=diff
==============================================================================
--- openoffice/branches/gbuild-reintegration/main/framework/source/fwi/threadhelp/transactionmanager.cxx (original)
+++ openoffice/branches/gbuild-reintegration/main/framework/source/fwi/threadhelp/transactionmanager.cxx Mon Aug  1 04:31:52 2016
@@ -104,7 +104,7 @@ TransactionManager::~TransactionManager(
                 You can step during this ones only from the left to the right side and start at left side again!
                 (This is necessary e.g. for refcounted objects!)
                 This call will block till all current existing transactions was finished.
-                Follow results occure:
+                Following results occur:
                     E_INIT        :  All requests on this implementation are refused.
                                         It's your decision to react in a right way.
 
@@ -194,7 +194,7 @@ void  TransactionManager::setWorkingMode
     @param      -
     @return     Current set mode.
 
-    @onerror    No error should occure.
+    @onerror    No error should occur.
 *//*-*****************************************************************************************************/
 EWorkingMode TransactionManager::getWorkingMode() const
 {

Modified: openoffice/branches/gbuild-reintegration/main/framework/source/inc/loadenv/loadenv.hxx
URL: http://svn.apache.org/viewvc/openoffice/branches/gbuild-reintegration/main/framework/source/inc/loadenv/loadenv.hxx?rev=1754701&r1=1754700&r2=1754701&view=diff
==============================================================================
--- openoffice/branches/gbuild-reintegration/main/framework/source/inc/loadenv/loadenv.hxx (original)
+++ openoffice/branches/gbuild-reintegration/main/framework/source/inc/loadenv/loadenv.hxx Mon Aug  1 04:31:52 2016
@@ -493,7 +493,7 @@ class LoadEnv : private ThreadHelpBase
                     so it contains the right type, a corresponding filter, may a
                     valid frame loader etc. In case detection failed, this descriptor
                     is corrected first, before a suitable exception will be thrown.
-                    (Excepting a RuntimeException occure!)
+                    (Excepting a RuntimeException occurs!)
 
             @attention  Not all types we know, are supported by filters. So it does not
                         indicates an error, if no suitable filter(loader etcpp will be found
@@ -534,7 +534,7 @@ class LoadEnv : private ThreadHelpBase
                     suppressed here.
                     In case handle failed all new created resources will be
                     removed before a suitable exception is thrown.
-                    (Excepting a RuntimeException occure!)
+                    (Excepting a RuntimeException occurs!)
 
             @return TODO
 
@@ -555,7 +555,7 @@ class LoadEnv : private ThreadHelpBase
                     used to load the content into this frame.
                     In case loading failed all new created resources will be
                     removed before a suitable exception is thrown.
-                    (Excepting a RuntimeException occure!)
+                    (Excepting a RuntimeException occurs!)
 
             @return TODO
 

Modified: openoffice/branches/gbuild-reintegration/main/framework/source/inc/loadenv/targethelper.hxx
URL: http://svn.apache.org/viewvc/openoffice/branches/gbuild-reintegration/main/framework/source/inc/loadenv/targethelper.hxx?rev=1754701&r1=1754700&r2=1754701&view=diff
==============================================================================
--- openoffice/branches/gbuild-reintegration/main/framework/source/inc/loadenv/targethelper.hxx (original)
+++ openoffice/branches/gbuild-reintegration/main/framework/source/inc/loadenv/targethelper.hxx Mon Aug  1 04:31:52 2016
@@ -110,7 +110,7 @@ class TargetHelper
                     and the value must not a well known special target.
 
             @param  sName
-                    the new frame name, which sould be checked.
+                    the new frame name, which should be checked.
          */
         static sal_Bool isValidNameForFrame(const ::rtl::OUString& sName);
 };

Modified: openoffice/branches/gbuild-reintegration/main/framework/source/jobs/job.cxx
URL: http://svn.apache.org/viewvc/openoffice/branches/gbuild-reintegration/main/framework/source/jobs/job.cxx?rev=1754701&r1=1754700&r2=1754701&view=diff
==============================================================================
--- openoffice/branches/gbuild-reintegration/main/framework/source/jobs/job.cxx (original)
+++ openoffice/branches/gbuild-reintegration/main/framework/source/jobs/job.cxx Mon Aug  1 04:31:52 2016
@@ -783,7 +783,7 @@ void SAL_CALL Job::queryTermination( /*I
     @short  inform us about office termination
     @descr  Instead of the method queryTermination(), here is no chance to disagree with that.
             We have to accept it and cancel all current processes inside.
-            It can occure only, if job was not already started if queryTermination() was called here ..
+            It can occur only if job was not already started if queryTermination() was called here ..
             Then we had not throwed a veto exception. But now we must agree with this situation and break
             all our internal processes. Its not a good idea to mark this instance as non startable any longer
             inside queryTermination() if no job was unning too. Because that would disable this job and may

Modified: openoffice/branches/gbuild-reintegration/main/framework/source/jobs/jobdata.cxx
URL: http://svn.apache.org/viewvc/openoffice/branches/gbuild-reintegration/main/framework/source/jobs/jobdata.cxx?rev=1754701&r1=1754700&r2=1754701&view=diff
==============================================================================
--- openoffice/branches/gbuild-reintegration/main/framework/source/jobs/jobdata.cxx (original)
+++ openoffice/branches/gbuild-reintegration/main/framework/source/jobs/jobdata.cxx Mon Aug  1 04:31:52 2016
@@ -158,7 +158,7 @@ JobData::~JobData()
 
 //________________________________
 /**
-    @short      initalize this instance as a job with configuration
+    @short      initialize this instance as a job with configuration
     @descr      They given alias can be used to address some configuraton data.
                 We read it and fill our internal structures. Of course old informations
                 will be lost doing so.
@@ -230,7 +230,7 @@ void JobData::setAlias( const ::rtl::OUS
 
 //________________________________
 /**
-    @short      initalize this instance as a job without configuration
+    @short      initialize this instance as a job without configuration
     @descr      This job has no configuration data. We have to forget all old informations
                 and set only some of them new, so this instance can work.
 
@@ -589,7 +589,7 @@ sal_Bool isEnabled( const ::rtl::OUStrin
     sal_Bool bValidUser  = aISOPattern.Matches(sUserTime );
 
     // We check for "isEnabled()" here only.
-    // Note further: ISO8601 formated strings can be compared as strings directly!
+    // Note further: ISO8601 formatted strings can be compared as strings directly!
     return (
             (!bValidAdmin && !bValidUser                         ) ||
             ( bValidAdmin &&  bValidUser && sAdminTime>=sUserTime)

Modified: openoffice/branches/gbuild-reintegration/main/framework/source/jobs/jobexecutor.cxx
URL: http://svn.apache.org/viewvc/openoffice/branches/gbuild-reintegration/main/framework/source/jobs/jobexecutor.cxx?rev=1754701&r1=1754700&r2=1754701&view=diff
==============================================================================
--- openoffice/branches/gbuild-reintegration/main/framework/source/jobs/jobexecutor.cxx (original)
+++ openoffice/branches/gbuild-reintegration/main/framework/source/jobs/jobexecutor.cxx Mon Aug  1 04:31:52 2016
@@ -244,7 +244,7 @@ void SAL_CALL JobExecutor::notifyEvent(
     catch( css::uno::Exception& )
     {}
 
-    // Special feature: If the events "OnNew" or "OnLoad" occures - we generate our own event "onDocumentOpened".
+    // Special feature: If the events "OnNew" or "OnLoad" occurs - we generate our own event "onDocumentOpened".
     if (
         (aEvent.EventName.equals(EVENT_ON_NEW )) ||
         (aEvent.EventName.equals(EVENT_ON_LOAD))
@@ -254,7 +254,7 @@ void SAL_CALL JobExecutor::notifyEvent(
             JobData::appendEnabledJobsForEvent(m_xSMGR, EVENT_ON_DOCUMENT_OPENED, lJobs);
     }
 
-    // Special feature: If the events "OnCreate" or "OnLoadFinished" occures - we generate our own event "onDocumentAdded".
+    // Special feature: If the events "OnCreate" or "OnLoadFinished" occurs - we generate our own event "onDocumentAdded".
     if (
         (aEvent.EventName.equals(EVENT_ON_CREATE       )) ||
         (aEvent.EventName.equals(EVENT_ON_LOAD_FINISHED))

Modified: openoffice/branches/gbuild-reintegration/main/framework/source/jobs/joburl.cxx
URL: http://svn.apache.org/viewvc/openoffice/branches/gbuild-reintegration/main/framework/source/jobs/joburl.cxx?rev=1754701&r1=1754700&r2=1754701&view=diff
==============================================================================
--- openoffice/branches/gbuild-reintegration/main/framework/source/jobs/joburl.cxx (original)
+++ openoffice/branches/gbuild-reintegration/main/framework/source/jobs/joburl.cxx Mon Aug  1 04:31:52 2016
@@ -563,7 +563,7 @@ void JobURL::impldbg_checkURL( /*IN*/ co
     @descr      It returns a representation of the internal object state
                 as string notation.
 
-    @returns    The formated string representation.
+    @returns    The formatted string representation.
 */
 ::rtl::OUString JobURL::impldbg_toString() const
 {

Modified: openoffice/branches/gbuild-reintegration/main/framework/source/layoutmanager/panelmanager.hxx
URL: http://svn.apache.org/viewvc/openoffice/branches/gbuild-reintegration/main/framework/source/layoutmanager/panelmanager.hxx?rev=1754701&r1=1754700&r2=1754701&view=diff
==============================================================================
--- openoffice/branches/gbuild-reintegration/main/framework/source/layoutmanager/panelmanager.hxx (original)
+++ openoffice/branches/gbuild-reintegration/main/framework/source/layoutmanager/panelmanager.hxx Mon Aug  1 04:31:52 2016
@@ -64,7 +64,7 @@
 namespace framework
 {
 		
-class PanelManager : private ThreadHelpBase // Struct for right initalization of mutex member! Must be first of baseclasses.
+class PanelManager : private ThreadHelpBase // Struct for right initialization of mutex member! Must be first of baseclasses.
 {
 	public:
 		PanelManager( 

Modified: openoffice/branches/gbuild-reintegration/main/framework/source/layoutmanager/toolbarlayoutmanager.hxx
URL: http://svn.apache.org/viewvc/openoffice/branches/gbuild-reintegration/main/framework/source/layoutmanager/toolbarlayoutmanager.hxx?rev=1754701&r1=1754700&r2=1754701&view=diff
==============================================================================
--- openoffice/branches/gbuild-reintegration/main/framework/source/layoutmanager/toolbarlayoutmanager.hxx (original)
+++ openoffice/branches/gbuild-reintegration/main/framework/source/layoutmanager/toolbarlayoutmanager.hxx Mon Aug  1 04:31:52 2016
@@ -81,7 +81,7 @@ namespace framework
 class ToolbarLayoutManager : public ::cppu::WeakImplHelper3< ::com::sun::star::awt::XDockableWindowListener,
                                                              ::com::sun::star::ui::XUIConfigurationListener,
                                                              ::com::sun::star::awt::XWindowListener >,
-                             private ThreadHelpBase // Struct for right initalization of mutex member! Must be first of baseclasses.
+                             private ThreadHelpBase // Struct for right initialization of mutex member! Must be first of baseclasses.
 {
     public:
         enum { DOCKINGAREAS_COUNT = 4 };

Modified: openoffice/branches/gbuild-reintegration/main/framework/source/services/autorecovery.cxx
URL: http://svn.apache.org/viewvc/openoffice/branches/gbuild-reintegration/main/framework/source/services/autorecovery.cxx?rev=1754701&r1=1754700&r2=1754701&view=diff
==============================================================================
--- openoffice/branches/gbuild-reintegration/main/framework/source/services/autorecovery.cxx (original)
+++ openoffice/branches/gbuild-reintegration/main/framework/source/services/autorecovery.cxx Mon Aug  1 04:31:52 2016
@@ -2398,7 +2398,7 @@ void AutoRecovery::implts_saveOneDoc(con
                                            AutoRecovery::TDocumentInfo&                        rInfo            ,
                                      const css::uno::Reference< css::task::XStatusIndicator >& xExternalProgress)
 {
-    // no document? => can occure if we loaded our configuration with files,
+    // no document? => can occur if we loaded our configuration with files,
     // which couldnt be recovered successfully. In such case we have all needed informations
     // excepting the real document instance!
 
@@ -2436,7 +2436,7 @@ void AutoRecovery::implts_saveOneDoc(con
     Reference< XDocumentRecovery > xDocRecover(rInfo.Document, css::uno::UNO_QUERY_THROW);
 
     // safe the state about "trying to save"
-    // ... we need it for recovery if e.g. a crash occures inside next line!
+    // ... we need it for recovery if e.g. a crash occurs inside next line!
     rInfo.DocumentState |= AutoRecovery::E_TRY_SAVE;
     implts_flushConfigItem(rInfo);
 
@@ -3538,7 +3538,7 @@ sal_Bool AutoRecovery::impl_enoughDiscSp
     return sal_False;
     #endif
 
-    // In case an error occures and we are not able to retrieve the needed information
+    // In case an error occurs and we are not able to retrieve the needed information
     // it's better to "disable" the feature ShowErrorOnFullDisc !
     // Otherwhise we start a confusing process of error handling ...
 
@@ -3590,7 +3590,7 @@ void AutoRecovery::impl_establishProgres
     // for loading documents into this frame)!
     // But if no frame exists ... we can try to locate it using any frame bound to the provided
     // document. Of course we must live without any frame in case the document does not exists at this
-    // point. But this state shouldn't occure. In such case xNewFrame should be valid ... hopefully .-)
+    // point. But this state shouldn't occur. In such case xNewFrame should be valid ... hopefully .-)
     css::uno::Reference< css::frame::XFrame > xFrame = xNewFrame;
     if (
         (!xFrame.is()       ) &&
@@ -3656,7 +3656,7 @@ void AutoRecovery::impl_forgetProgress(c
     // for loading documents into this frame)!
     // But if no frame exists ... we can try to locate it using any frame bound to the provided
     // document. Of course we must live without any frame in case the document does not exists at this
-    // point. But this state shouldn't occure. In such case xNewFrame should be valid ... hopefully .-)
+    // point. But this state shouldn't occur. In such case xNewFrame should be valid ... hopefully .-)
     css::uno::Reference< css::frame::XFrame > xFrame = xNewFrame;
     if (
         (!xFrame.is()       ) &&

Modified: openoffice/branches/gbuild-reintegration/main/framework/source/services/desktop.cxx
URL: http://svn.apache.org/viewvc/openoffice/branches/gbuild-reintegration/main/framework/source/services/desktop.cxx?rev=1754701&r1=1754700&r2=1754701&view=diff
==============================================================================
--- openoffice/branches/gbuild-reintegration/main/framework/source/services/desktop.cxx (original)
+++ openoffice/branches/gbuild-reintegration/main/framework/source/services/desktop.cxx Mon Aug  1 04:31:52 2016
@@ -1034,7 +1034,7 @@ css::uno::Reference< css::frame::XFrame
     //    We doesn't support search for following special targets.
     //    If we reject this requests - we mustnt check for such names
     //    in following code again and again. If we do not so -wrong
-    //    search results can occure!
+    //    search results can occur!
     //-----------------------------------------------------------------------------------------------------
     if (
         (sTargetFrameName==SPECIALTARGET_DEFAULT  )   ||    // valid for dispatches - not for findFrame()!
@@ -1145,7 +1145,7 @@ css::uno::Reference< css::frame::XFrame
         //-------------------------------------------------------------------------------------------------
         // II.III) CHILDREN
         //  Search on all children for the given target name.
-        //  An empty name value can't occure here - because it must be already handled as "_self"
+        //  An empty name value can't occur here - because it must be already handled as "_self"
         //  before. Used helper function of container doesn't create any frame.
         //  It makes a deep search only.
         //-------------------------------------------------------------------------------------------------
@@ -1249,7 +1249,7 @@ void SAL_CALL Desktop::dispose()
     @interface  XComponent
     @short      add/remove listener for dispose events
     @descr      Add an event listener to this object, if you whish to get informations
-                about our dieing!
+                about our dying!
                 You must releas ethis listener reference during your own disposing() method.
 
     @attention  Our container is threadsafe himeslf. So we doesn't need any lock here.
@@ -1351,7 +1351,7 @@ void SAL_CALL Desktop::disposing( const
                 of our own called method.
 
     @attention  a)
-                Normal loop in loadComponentFromURL() breaks on setted member m_eLoadState during callback statusChanged().
+                Normal loop in loadComponentFromURL() breaks on set member m_eLoadState during callback statusChanged().
                 But these interaction feature implements second way to do so! So we must look on different callbacks
                 for same operation ... and live with it.
                 b)
@@ -1374,7 +1374,7 @@ void SAL_CALL Desktop::handle( const css
     TransactionGuard aTransaction( m_aTransactionManager, E_HARDEXCEPTIONS );
 
     // Don't check incoming request!
-    // If somewhere starts interaction without right parameter - he maked something wrong.
+    // If somewhere starts interaction without right parameter - he made something wrong.
     // loadComponentFromURL() waits for thjese event - otherwise it yield for ever!
 
     // get packed request and work on it first

Modified: openoffice/branches/gbuild-reintegration/main/framework/source/services/frame.cxx
URL: http://svn.apache.org/viewvc/openoffice/branches/gbuild-reintegration/main/framework/source/services/frame.cxx?rev=1754701&r1=1754700&r2=1754701&view=diff
==============================================================================
--- openoffice/branches/gbuild-reintegration/main/framework/source/services/pathsettings.cxx (original)
+++ openoffice/branches/gbuild-reintegration/main/framework/source/services/pathsettings.cxx Mon Aug  1 04:31:52 2016
@@ -949,7 +949,7 @@ void PathSettings::impl_setPathValue(
 
     // first we should try to store the changed (copied!) path ...
     // In case an error occure on saving time an exception is thrown ...
-    // If no exception occures we can update our internal cache (means
+    // If no exception occurs we can update our internal cache (means
     // we can overwrite pOrgPath !
     impl_storePath(aChangePath);
     pOrgPath->takeOver(aChangePath);

Modified: openoffice/branches/gbuild-reintegration/main/framework/source/uiconfiguration/globalsettings.cxx
URL: http://svn.apache.org/viewvc/openoffice/branches/gbuild-reintegration/main/framework/source/uiconfiguration/globalsettings.cxx?rev=1754701&r1=1754700&r2=1754701&view=diff
==============================================================================
--- openoffice/branches/gbuild-reintegration/main/framework/source/uiconfiguration/globalsettings.cxx (original)
+++ openoffice/branches/gbuild-reintegration/main/framework/source/uiconfiguration/globalsettings.cxx Mon Aug  1 04:31:52 2016
@@ -79,7 +79,7 @@ namespace framework
 
 class GlobalSettings_Access : public ::com::sun::star::lang::XComponent	     ,
                               public ::com::sun::star::lang::XEventListener  ,
-						      private ThreadHelpBase						 ,	// Struct for right initalization of mutex member! Must be first of baseclasses.
+						      private ThreadHelpBase						 ,	// Struct for right initialization of mutex member! Must be first of baseclasses.
 						      public ::cppu::OWeakObject
 {
 	public:

Modified: openoffice/branches/gbuild-reintegration/main/framework/source/uiconfiguration/imagemanagerimpl.hxx
URL: http://svn.apache.org/viewvc/openoffice/branches/gbuild-reintegration/main/framework/source/uiconfiguration/imagemanagerimpl.hxx?rev=1754701&r1=1754700&r2=1754701&view=diff
==============================================================================
--- openoffice/branches/gbuild-reintegration/main/framework/source/uiconfiguration/imagemanagerimpl.hxx (original)
+++ openoffice/branches/gbuild-reintegration/main/framework/source/uiconfiguration/imagemanagerimpl.hxx Mon Aug  1 04:31:52 2016
@@ -121,7 +121,7 @@ namespace framework
             oslInterlockedCount                                                              m_nRefCount;
     };
 
-    class ImageManagerImpl : public ThreadHelpBase	// Struct for right initalization of mutex member! Must be first of baseclasses.
+    class ImageManagerImpl : public ThreadHelpBase	// Struct for right initialization of mutex member! Must be first of baseclasses.
     {
         public:
 

Modified: openoffice/branches/gbuild-reintegration/main/framework/source/uiconfiguration/uiconfigurationmanagerimpl.hxx
URL: http://svn.apache.org/viewvc/openoffice/branches/gbuild-reintegration/main/framework/source/uiconfiguration/uiconfigurationmanagerimpl.hxx?rev=1754701&r1=1754700&r2=1754701&view=diff
==============================================================================
--- openoffice/branches/gbuild-reintegration/main/framework/source/uiconfiguration/uiconfigurationmanagerimpl.hxx (original)
+++ openoffice/branches/gbuild-reintegration/main/framework/source/uiconfiguration/uiconfigurationmanagerimpl.hxx Mon Aug  1 04:31:52 2016
@@ -69,7 +69,7 @@
 
 namespace framework
 {
-    class UIConfigurationManagerImpl :   public ThreadHelpBase		// Struct for right initalization of mutex member! Must be first of baseclasses.
+    class UIConfigurationManagerImpl :   public ThreadHelpBase		// Struct for right initialization of mutex member! Must be first of baseclasses.
     {
         public:
             //  XInterface, XTypeProvider, XServiceInfo

Modified: openoffice/branches/gbuild-reintegration/main/framework/source/uielement/newmenucontroller.cxx
URL: http://svn.apache.org/viewvc/openoffice/branches/gbuild-reintegration/main/framework/source/uielement/newmenucontroller.cxx?rev=1754701&r1=1754700&r2=1754701&view=diff
==============================================================================
--- openoffice/branches/gbuild-reintegration/main/framework/source/uielement/newmenucontroller.cxx (original)
+++ openoffice/branches/gbuild-reintegration/main/framework/source/uielement/newmenucontroller.cxx Mon Aug  1 04:31:52 2016
@@ -457,7 +457,7 @@ void SAL_CALL NewMenuController::itemSel
 
     if ( xDispatch.is() )
     {
-        // Call dispatch asychronously as we can be destroyed while dispatch is
+        // Call dispatch asynchronously as we can be destroyed while dispatch is
         // executed. VCL is not able to survive this as it wants to call listeners
         // after select!!!
         NewDocument* pNewDocument = new NewDocument;

Modified: openoffice/branches/gbuild-reintegration/main/framework/source/uielement/recentfilesmenucontroller.cxx
URL: http://svn.apache.org/viewvc/openoffice/branches/gbuild-reintegration/main/framework/source/uielement/recentfilesmenucontroller.cxx?rev=1754701&r1=1754700&r2=1754701&view=diff
==============================================================================
--- openoffice/branches/gbuild-reintegration/main/framework/source/uielement/recentfilesmenucontroller.cxx (original)
+++ openoffice/branches/gbuild-reintegration/main/framework/source/uielement/recentfilesmenucontroller.cxx Mon Aug  1 04:31:52 2016
@@ -266,7 +266,7 @@ void RecentFilesMenuController::executeE
 
     if ( xDispatch.is() )
     {
-        // Call dispatch asychronously as we can be destroyed while dispatch is
+        // Call dispatch asynchronously as we can be destroyed while dispatch is
         // executed. VCL is not able to survive this as it wants to call listeners
         // after select!!!
         LoadRecentFile* pLoadRecentFile = new LoadRecentFile;

Modified: openoffice/branches/gbuild-reintegration/main/framework/source/xml/acceleratorconfigurationreader.cxx
URL: http://svn.apache.org/viewvc/openoffice/branches/gbuild-reintegration/main/framework/source/xml/acceleratorconfigurationreader.cxx?rev=1754701&r1=1754700&r2=1754701&view=diff
==============================================================================
--- openoffice/branches/gbuild-reintegration/main/framework/source/xml/acceleratorconfigurationreader.cxx (original)
+++ openoffice/branches/gbuild-reintegration/main/framework/source/xml/acceleratorconfigurationreader.cxx Mon Aug  1 04:31:52 2016
@@ -51,7 +51,7 @@
 namespace framework{
 
 //-----------------------------------------------
-/* Throws a SaxException in case a wrong formated XML
+/* Throws a SaxException in case a wrong formatted XML
    structure was detected.
    
    This macro combined the given comment with a generic
@@ -127,7 +127,7 @@ void SAL_CALL AcceleratorConfigurationRe
     EXMLElement eElement = AcceleratorConfigurationReader::implst_classifyElement(sElement);
     
     // Note: We handle "accel:item" before "accel:acceleratorlist" to perform this operation.
-    // Because an item occures very often ... a list should occure one times only!
+    // Because an item occurs very often ... a list should occur one times only!
     if (eElement == E_ELEMENT_ITEM)
     {
         if (!m_bInsideAcceleratorList)
@@ -222,7 +222,7 @@ void SAL_CALL AcceleratorConfigurationRe
     EXMLElement eElement = AcceleratorConfigurationReader::implst_classifyElement(sElement);
     
     // Note: We handle "accel:item" before "accel:acceleratorlist" to perform this operation.
-    // Because an item occures very often ... a list should occure one times only!
+    // Because an item occurs very often ... a list should occur one times only!
     if (eElement == E_ELEMENT_ITEM)
     {
         if (!m_bInsideAcceleratorItem)
--- openoffice/branches/gbuild-reintegration/main/framework/source/services/frame.cxx (original)
+++ openoffice/branches/gbuild-reintegration/main/framework/source/services/frame.cxx Mon Aug  1 04:31:52 2016
@@ -584,7 +584,7 @@ void SAL_CALL Frame::initialize( const c
     // This must be the first call of this method!
     // We should initialize our object and open it for working.
     // Set the new window.
-    LOG_ASSERT2( m_xContainerWindow.is()==sal_True, "Frame::initialize()", "Leak detected! This state should never occure ..." )
+    LOG_ASSERT2( m_xContainerWindow.is()==sal_True, "Frame::initialize()", "Leak detected! This state should never occur ..." )
     m_xContainerWindow = xWindow;
 
     // if window is initially visible, we will never get a windowShowing event
@@ -800,7 +800,7 @@ css::uno::Reference< css::frame::XFrame
     //    We doesn't support search for following special targets.
     //    If we reject this requests - we mustnt check for such names
     //    in following code again and again. If we do not so -wrong
     //    search results can occure!
     //-----------------------------------------------------------------------------------------------------
     if (
         (sTargetFrameName==SPECIALTARGET_DEFAULT  )   ||    // valid for dispatches - not for findFrame()!
@@ -937,7 +937,7 @@ css::uno::Reference< css::frame::XFrame
         //-------------------------------------------------------------------------------------------------
         // II.II) CHILDREN
         //  Search on all children for the given target name.
         //  An empty name value can't occure here - because it must be already handled as "_self"
         //  before. Used helper function of container doesn't create any frame.
         //  It makes a deep search only.
         //-------------------------------------------------------------------------------------------------
@@ -1017,7 +1017,7 @@ css::uno::Reference< css::frame::XFrame
             //-------------------------------------------------------------------------------------------------
             // II.III.II) PARENT
             //  Forward search to our parent (if he exists.)
             //  To prevent us against recursive and superflous calls (which can occure if we allow him
             //  to search on his childrens too) we must change used search flags.
             //-------------------------------------------------------------------------------------------------
             if (
@@ -1070,7 +1070,7 @@ css::uno::Reference< css::frame::XFrame
 	@param		-
 	@return		true, if is it a top frame ... false otherwise.
 
-	@onerror	No error should occure!
+	@onerror	No error should occur!
 *//*-*****************************************************************************************************/
 sal_Bool SAL_CALL Frame::isTop() throw( css::uno::RuntimeException )
 {
@@ -1286,7 +1286,7 @@ void SAL_CALL Frame::deactivate() throw(
 	@param		-
 	@return		true if active, false otherwise.
 
-	@onerror	No error should occure.
+	@onerror	No error should occur.
 *//*-*****************************************************************************************************/
 sal_Bool SAL_CALL Frame::isActive() throw( css::uno::RuntimeException )
 {
@@ -1947,7 +1947,7 @@ void SAL_CALL Frame::dispose() throw( cs
         remove himself at this instance ...
         Release m_xFramesHelper after that ... it's the same problem between parent and child!
         "m_xParent->getFrames()->remove( xThis );" needs this helper ...
-        Otherwise we get a null reference and could finish removing successfuly.
+        Otherwise we get a null reference and could finish removing successfully.
         => You see: Order of calling operations is important!!!
      */
 	implts_forgetSubFrames();
@@ -2547,7 +2547,7 @@ void SAL_CALL Frame::setActionLocks( sal
     WriteGuard aWriteLock( m_aLock );
     // Attention: If somewhere called resetActionLocks() before and get e.g. 5 locks ...
     //            and tried to set these 5 ones here after his operations ...
-    //            we can't ignore setted requests during these two calls!
+    //            we can't ignore set requests during these two calls!
     //            So we must add(!) these 5 locks here.
     m_nExternalLockCount = m_nExternalLockCount + nLock;
 }
@@ -800,7 +800,7 @@ css::uno::Reference< css::frame::XFrame
     //    If we reject this requests - we mustnt check for such names
     //    in following code again and again. If we do not so -wrong
-    //    search results can occure!
+    //    search results can occur!
     //-----------------------------------------------------------------------------------------------------
     if (
@@ -937,7 +937,7 @@ css::uno::Reference< css::frame::XFrame
         // II.II) CHILDREN
         //  Search on all children for the given target name.
-        //  An empty name value can't occure here - because it must be already handled as "_self"
+        //  An empty name value can't occur here - because it must be already handled as "_self"
         //  before. Used helper function of container doesn't create any frame.
         //  It makes a deep search only.
@@ -1017,7 +1017,7 @@ css::uno::Reference< css::frame::XFrame
             // II.III.II) PARENT
             //  Forward search to our parent (if he exists.)
-            //  To prevent us against recursive and superflous calls (which can occure if we allow him
+            //  To prevent us against recursive and superflous calls (which can occur if we allow him
             //  to search on his childrens too) we must change used search flags.
             //-------------------------------------------------------------------------------------------------

Modified: openoffice/branches/gbuild-reintegration/main/framework/source/services/pathsettings.cxx
URL: http://svn.apache.org/viewvc/openoffice/branches/gbuild-reintegration/main/framework/source/services/pathsettings.cxx?rev=1754701&r1=1754700&r2=1754701&view=diff
==============================================================================